==> wlp-webProfile7-24.0.0.3.zip: OSGI-INF/welcome/nls/pt-br/messages.js <==
var messages = {
    WELCOME: "Bem-vindo ao Liberty",
    WEBSPHERE_LIBERTY_LOGO: "Logotipo do WebSphere Liberty",
    OPEN_LIBERTY_LOGO: "Logotipo do Open Liberty",
    WELCOME_SECTION: "Seção de boas-vindas",
    WELCOME_SECTION_CONTENT: "Conteúdo da seção de boas-vindas",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Beta",
    HOW_TO_SETUP_ADMIN_CENTER: "Como configurar o Admin Center",
    OPEN_ADMIN_CENTER: "Abrir o Admin Center",
    ADDITIONAL_RESOURCES: "Recursos adicionais",
    EXTERNAL_RESOURCES: "Recursos Externos",
    OPEN_LIBERT_SUPPORT: "Comunidade do Open Liberty",
    WEBSPHERE_LIBERTY_DOC: "Documentação do WebSphere Liberty",
    APPLICABLE_CONTENT: "Todo o conteúdo do Open Liberty é aplicável ao WebSphere Liberty:",
    OPEN_LIBERTY_DOC: "Documentação do Open Liberty",
    OPEN_LIBERTY_GUIDES: "Guias do Open Liberty",
    WEBSPHERE_LIBERTY_FORUM: "Fórum do WebSphere Liberty",
    HEADER_UPDATE_AVAILABLE: "Atualização disponível: ",
    HEADER_DOWNLOAD_LINK: "Clique para fazer o download do {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Atualização disponível. Clique para fazer o download do {0}", // Product name
    COPYRIGHT: "copyright",
    IBM_LOGO: "Logotipo IBM",
    IBM_LICENSED: "Licensed Materials — Property of IBM © Copyright IBM Corp. 1997, 2019. Todos os Direitos Reservados. IBM e o logotipo IBM são marcas comerciais ou marcas registradas da International Business Machines Corp., registradas em várias jurisdições no mundo inteiro. Outros nomes de produtos e serviços podem ser marcas registradas da IBM ou outras empresas. Uma lista atual de marcas comerciais IBM está disponível na Web em {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Informações de copyright e de marca registrada",
    CONTEXT_ROOT_NOT_FOUND: "Raiz de contexto não encontrada",
    UPDATE_BANNER_CLOSE_BUTTON: "Fechar o banner",
    UPDATE_BANNER_SECTION: "Seção de atualização de banner",
    UPDATE_BANNER_SECTION_CONTENT: "Conteúdo da seção de atualização de banner",
    BUILT_ON: "Desenvolvido com ",
    LINKS: "Links: "
};

==> wlp-webProfile8-20.0.0.8.zip: OSGI-INF/welcome/nls/pt-br/messages.js <==
var messages = {
    WELCOME: "Bem-vindo ao Liberty",
    WEBSPHERE_LIBERTY_LOGO: "Logotipo do WebSphere Liberty",
    WELCOME_SECTION: "Seção de boas-vindas",
    WELCOME_SECTION_CONTENT: "Conteúdo da seção de boas-vindas",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Beta",
    HOW_TO_SETUP_ADMIN_CENTER: "Como configurar o Admin Center",
    OPEN_ADMIN_CENTER: "Abrir o Admin Center",
    ADDITIONAL_RESOURCES: "Recursos adicionais",
    EXTERNAL_RESOURCES: "Recursos Externos",
    WASDEV: "Comunidade do WASdev",
    LIBERTY_DOC: "Documentação do Liberty",
    WASDEV_FORUM: "Fórum do WASdev",
    HEADER_UPDATE_AVAILABLE: "Atualização disponível: ",
    HEADER_DOWNLOAD_LINK: "Clique para fazer download {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Atualização disponível. Clique para fazer download {0}", // Product name
    COPYRIGHT: "copyright",
    IBM_LOGO: "Logotipo IBM",
    IBM_LICENSED: "Licensed Materials — Property of IBM © Copyright IBM Corp. 1997, 2019. Todos os Direitos Reservados. IBM e o logotipo IBM são marcas comerciais ou marcas registradas da International Business Machines Corp., registradas em várias jurisdições no mundo inteiro. Outros nomes de produtos e serviços podem ser marcas registradas da IBM ou outras empresas. Uma lista atual de marcas comerciais IBM está disponível na Web em {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Informações de copyright e de marca registrada",
    CONTEXT_ROOT_NOT_FOUND: "Raiz de contexto não encontrada",
    UPDATE_BANNER_CLOSE_BUTTON: "Fechar o banner",
    UPDATE_BANNER_SECTION: "Seção de atualização de banner",
    UPDATE_BANNER_SECTION_CONTENT: "Conteúdo da seção de atualização de banner",
    BUILT_ON: "Desenvolvido com ",
    LINKS: "Links: "
};
